#
# spec file for package python-aioitertools
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python3-%{**}}
%define skip_python2 1
Name:           python-aioitertools
Version:        0.11.0
Release:        1.10
Summary:        Itertools and builtins for AsyncIO and mixed iterables
License:        MIT
Group:          Development/Languages/Python
URL:            https://aioitertools.omnilib.dev
Source:         https://files.pythonhosted.org/packages/source/a/aioitertools/aioitertools-%{version}.tar.gz
BuildRequires:  %{python_module asyncio}
BuildRequires:  %{python_module flit-core > 2}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module typing_extensions if %python-base < 3.10}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if 0%{?python_version_nodots} < 310
Requires:       python-typing_extensions >= 4.0
%endif
BuildArch:      noarch
%python_subpackages

%description
Implementation of itertools, builtins, and more for AsyncIO and mixed-type iterables.

%prep
%autosetup -p1 -n aioitertools-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pyunittest -v

%files %{python_files}
%doc README.md CHANGELOG.md
%license LICENSE
%{python_sitelib}/aioitertools
%{python_sitelib}/aioitertools-%{version}*-info

%changelog
* Mon Oct 17 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.11.0:
  - New: `before_and_after` from `more_itertools` (#111)
  - Removed: `loop` parameter is now removed from asyncio functions (#136)
  - Docs: fixed docstring for `builtins.max` (#107)
  - Docs: can now be built without installing package (#135)
  - Python: Added support for Python 3.11 (#133)
  - Python: Deprecated support for Python 3.6, to be removed in 0.12.0
- from version 0.10.0:
  - New `as_generated()` function for consuming multiple iterables (#99)
- from version 0.10.0b1:
  - New `as_generated()` function for consuming multiple iterables (#99)
- from version 0.9.0:
  - Python 3.10 support (#84, #97)
  - Fixed: `as_completed()` will now cancel pending tasks when the timeout
    threshold has been reached.
  - Fixed: `zip()` will now gather all tasks correctly when exceptions are
    raised, resulting in no pending tasks being unawaited.
  - DEPRECATED: `loop` parameters to asyncio functions are ignored, and will
    be removed entirely in v0.11.0. This is for 3.10 compatibility, as well
    as to follow common practice and guidance around asyncio.
- Drop patches for issues fixed upstream
  - aioitertools-remove-loop.patch
- Switch build system to pyproject.toml
- Update BuildRequires from pyproject.toml
* Thu Jan  6 2022 Ben Greiner <code@bnavigator.de>
- Add aioitertools-remove-loop.patch for python310 compatibility
  gh#omnilib/aioitertools#84
* Tue Aug 17 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.8.0:
  - Added `builtins.any()` and `builtins.all()` (#44)
  - `builtins.next()` takes an optional `default` parameter (#40, #41)
  - `asyncio.gather()` now handles cancellation (#64)
  - Better exception handling in `itertools.tee()` (#47)
  - Removed dependency on typing_extensions for Python 3.8 and newer (#49)
  - Improved documentation and formatting
- Drop patches for issues fixed upstream
  - stdlib-typing_extensions.patch
* Thu May 13 2021 Matej Cepl <mcepl@suse.com>
- Update to 0.7.1:
  - Fix groupby() not working with empty iterables (#39)
- Add stdlib-typing_extensions.patch making typing_extensions
  package just an optional requirement (gh#omnilib/aioitertools#49).
* Fri Jul  3 2020 Marketa Calabkova <mcalabkova@suse.com>
- Initial packaging (v0.7.0)
